<?php

namespace Longman\TelegramBot\Commands\SystemCommands;

/**
 * This file is part of the TelegramBot package.
 *
 * (c) Avtandil Kikabidze aka LONGMAN <akalongman@gmail.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

use Longman\TelegramBot\Commands\SystemCommand;
use Longman\TelegramBot\Request;

/**
 * Start command.
 *
 * Gets executed when a user first starts using the bot.
 */
class StartCommand extends SystemCommand {

  /**
   * Name.
   *
   * @var string
   */
  protected $name = 'start';

  /**
   * Description.
   *
   * @var string
   */
  protected $description = 'Start command';

  /**
   * Usage.
   *
   * @var string
   */
  protected $usage = '/start';

  /**
   * Version.
   *
   * @var string
   */
  protected $version = '1.1.0';

  /**
   * Private flag.
   *
   * @var bool
   */
  protected $private_only = TRUE;

  /**
   * Command execute method.
   *
   * @throws \Longman\TelegramBot\Exception\TelegramException
   * @return \Longman\TelegramBot\Entities\ServerResponse
   */
  public function execute() {
    $message = $this->getMessage();
    $chat_id = $message->getChat()->getId();
    $text    = "Hi there!\nNo commands";

    $data = [
      'chat_id' => $chat_id,
      'text'    => $text,
    ];
    return Request::sendMessage($data);
  }

}
