<?php

namespace Drupal\telega_bot\Service;

use Drupal\Core\Entity\EntityInterface;
use Longman\TelegramBot\Telegram;
use Longman\TelegramBot\Exception\TelegramException;
use Symfony\Component\Yaml\Yaml;
use Drupal\datetime\Plugin\Field\FieldType\DateTimeItemInterface;

/**
 * Bot service.
 */
class Bot {

  /**
   * Creates a new Bot manager.
   */
  public function __construct() {
    $this->etype = \Drupal::service('entity_type.manager');
    $this->d = \Drupal::service('date.formatter');
    $this->df = DateTimeItemInterface::DATETIME_STORAGE_FORMAT;
    // Enable admin users
    // $telegram->enableAdmins($admin_users);
    // Set custom Upload and Download paths
    // $telegram->setDownloadPath(__DIR__ . '/Download');
    // $telegram->setUploadPath(__DIR__ . '/Upload');
    // Here you can set some command specific parameters
    // e.g. Google geocode/timezone api key for /date command
    // $telegram->setCommandConfig('date', [
    // 'google_api_key' => 'your_google_api_key_here'
    // ]);
    // Botan.io integration
    // $telegram->enableBotan('your_botan_token');
    // End Extra, see https://github.com/php-telegram-bot/example-bot //.
    // https://github.com/php-telegram-bot/core //.
  }

  /**
   * Init a new Bot manager.
   */
  public function init(EntityInterface $entity) {
    $this->entity = $entity;
    $this->id = $entity->id();
    $this->key = $entity->token->value;
    $this->name = $entity->name->value;
    try {
      $telegram = new Telegram($this->key, $this->name);
      $type = $entity->type->value;
      if ($type) {
        $plugin_manager = \Drupal::service('plugin.manager.telega_bot');
        $plugin = $plugin_manager->createInstance($type, ['bot' => $entity]);
        $commands_paths = $plugin->commands;
        $telegram->addCommandsPaths($commands_paths);
        $telegram->enableLimiter();
      }
      $this->telegram = $telegram;
    }
    catch (TelegramException $e) {
      $error = $e->getMessage();
      return $error;
    }
    return $this;
  }

  /**
   * Check Valuer in array.
   */
  private function getVal($data, $key) {
    $result = FALSE;
    if (!empty($data[$key])) {
      $result = $data[$key];
    }
    return $result;
  }

  /**
   * Check Valuer in array.
   */
  private function getTitle($data, $type) {
    $result = FALSE;
    $bot = $this->name;
    $title = "";
    $n = [];
    if (!empty($data['first_name'])) {
      $n[] = $data['first_name'];
    }
    if (!empty($data['last_name'])) {
      $n[] = $data['last_name'];
    }
    if (!empty($data['username'])) {
      $n[] = "@{$data['username']}";
    }
    if (empty($n)) {
      $n[] = $data['id'];
    }
    $name = implode(" ", $n);
    if ($type == 'user') {
      $title = $name;
    }
    if ($type == 'chat') {
      if (!empty($data['title'])) {
        $title = $data['title'];
      }
      else {
        $title = "{$name} | @$bot";
      }
    }
    return $title;
  }

  /**
   * User.
   */
  private function user($data) {
    if (!empty($data['message']['from'])) {
      $storage = $this->etype->getStorage('telega_user');
      $u = $data['message']['from'];
      $user = $this->query($storage, $u['id']);
      if (!$user) {
        $user = $storage->create([
          'title' => $this->getTitle($u, 'user'),
          'key' => $u['id'],
          'bot' => $u['is_bot'],
          'name' => $this->getVal($u, 'username'),
          'first_name' => $this->getVal($u, 'first_name'),
          'last_name' => $this->getVal($u, 'last_name'),
          'lang' => $u['language_code'],
          'yaml' => FALSE,
          'data' => FALSE,
        ]);
        $user->save();
      }
      return $user;
    }
  }

  /**
   * Chat.
   */
  private function chat($data) {
    if (!empty($data['message']['chat'])) {
      $c = $data['message']['chat'];
      $storage = $this->etype->getStorage('telega_chat');
      $chat = $this->query($storage, $c['id'], $c['type'] == 'private');
      if (!$chat) {
        $chat = $storage->create([
          'title' => $this->getTitle($c, 'chat'),
          'key' => $c['id'],
          'type' => $c['type'],
          'name' => $this->getVal($c, 'username'),
          'first_name' => $this->getVal($c, 'first_name'),
          'last_name' => $this->getVal($c, 'last_name'),
          'bot_id' => $this->id,
          'all_admins' => FALSE,
          'key_old' => FALSE,
          // 'yaml' => Yaml::dump($c),
          // 'data' => $c,
        ]);
        $chat->save(TRUE);
      }
      return $chat;
    }
  }

  /**
   * Query.
   */
  private function query($storage, $key, $bot = FALSE) {
    $entities = [];
    $query = $storage->getQuery()
      ->condition('status', 1)
      ->condition('key', $key)
      ->range(0, 1);
    if ($bot) {
      $query->condition('bot_id', $this->id);
    }
    $ids = $query->execute();
    if (!empty($ids)) {
      foreach ($storage->loadMultiple($ids) as $id => $entity) {
        $entities[$id] = $entity;
      }
    }
    return array_shift($entities);
  }

  /**
   * Set webhook.
   */
  public function setup() {
    try {
      $id = $this->id;
      $host = \Drupal::request()->getSchemeAndHttpHost();
      $webhook = "$host/telega/bot/$id/webhook";
      $result = $this->telegram->setWebhook($webhook);
      if ($result->isOk()) {
        return $result->getDescription();
      }
      else {
        return "error";
      }
    }
    catch (TelegramException $e) {
      return $e->getMessage();
    }
  }

  /**
   * Set webhook.
   */
  public function hook($bot, $data) {
    $this->init($bot);
    // \Drupal::logger('telega_bot')->warning(print_r($data, TRUE)); // Debug.
    if (!empty($data['message'])) {
      $user = $this->user($data);
      $chat = $this->chat($data);
      $m = $data['message'];
      $message = [
        'title' => mb_substr($m['text'], 0, 40),
        'key' => $m['message_id'],
        'date' => $this->d->format($m['date'], 'custom', $this->df),
        'text' => $this->getVal($m, 'text'),
        'bot_id' => $this->id,
        'chat_id' => $chat->id(),
        'user_id' => $bot->id(),
        'entities' => FALSE,
        'yaml' => Yaml::dump($this->getVal($m, 'entities')),
        'data' => FALSE,
      ];
      $storage = $this->etype->getStorage('telega_message');
      $storage->create($message)->save();
    }
    try {
      $this->telegram->handle();
    }
    catch (TelegramException $e) {
      $message = $e->getMessage();
      $message = \Drupal::logger('telega_bot')->error($message);
      return $message;
    }
  }

}
